@@ -350,6 +350,14 @@ class EnvBase(NamespacedMutableMapping,
                    |      |      +––––– mapping key (uppercased)
                    |      +–––––––––––– namespace value (uppercased)
                    +––––––––––––––––––– app name (uppercased)
+        
+            … this corresponds to the namespaced key “iheard:youlike” from
+            an instance of “clu.config.env.Environ” initialized for the
+            appname “yodogg” (say). You can have multiple namespaces in an
+            environment key like the above – just add underscores. For
+            example, “YODOGG_I_HEARD_YOU_LIKE” differs from our given example
+            because it translates to the namespaced key “i:heard:you:like”,
+            which, you will note, is different.
         """
         if not namespace:
             return cls.appname.upper() + ENVIRONS_SEP
@@ -374,6 +382,14 @@ class EnvBase(NamespacedMutableMapping,
                    |      |      +––––– mapping key (uppercased)
                    |      +–––––––––––– namespace value (uppercased)
                    +––––––––––––––––––– app name (uppercased)
+        
+            … this corresponds to the namespaced key “iheard:youlike” from
+            an instance of “clu.config.env.Environ” initialized for the
+            appname “yodogg” (say). You can have multiple namespaces in an
+            environment key like the above – just add underscores. For
+            example, “YODOGG_I_HEARD_YOU_LIKE” differs from our given example
+            because it translates to the namespaced key “i:heard:you:like”,
+            which, you will note, is different.
         """
         return cls.prefix(namespace=namespace) + str(key).upper()
     
